package application;

import java.io.IOException;
import java.util.Optional;

import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.control.Alert;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.control.Button;
import javafx.scene.control.ButtonBar.ButtonData;
import javafx.scene.control.ButtonType;
import javafx.scene.control.CheckBox;
import javafx.scene.control.ComboBox;
import javafx.scene.control.Label;
import javafx.scene.layout.VBox;
import javafx.scene.paint.Color;
import javafx.scene.shape.Rectangle;

public class AlertDialogAndStageMainVBox extends VBox {
	
    @FXML
    private ComboBox<String> comboBoxAlertType;

    @FXML
    private CheckBox checkBoxDefault;

    @FXML
    private Button buttonAlert;

    @FXML
    private Button buttonDialog;

    @FXML
    private Button buttonStage;

    @FXML
    private Label labelResult;

    @FXML
    private Rectangle rectangle;

	private String[] stringAlertTypes = {"INFORMATION", "CONFIRMATION", "WARNING", "ERROR"};
	private AlertType[] alertTypes = {AlertType.INFORMATION, AlertType.CONFIRMATION, AlertType.WARNING, AlertType.ERROR};
	private String[] titles = {"", "mF", "x", "G["};
	private String[] headers = {"N̐", "L̊mF", "pԂɊւx", "G[ł"};
	private String[] contents = {"N2020NłB", "͂ꂽO ZZ lłB\n΁uOKvԈĂ΁uvĉB", "ԗpĂ܂BxIAx肭B", "0ł͊܂B"};
	
    @FXML
    private void initialize() {
    	comboBoxAlertType.getItems().setAll(stringAlertTypes);
    	comboBoxAlertType.setValue("INFORMATION");
    	
    	setHandlers();
    }
    
    private void setHandlers() {
    	
    	buttonAlert.setOnAction(new EventHandler<ActionEvent>() {

			@Override
			public void handle(ActionEvent event) {
				resetResult();

				int i = comboBoxAlertType.getSelectionModel().getSelectedIndex();
				Alert alert = new Alert(alertTypes[i]);
				alert.setTitle(titles[i]);
				alert.setHeaderText(headers[i]);
				alert.setContentText(contents[i]);
				if (!checkBoxDefault.isSelected()) {
					if (i == 1) { // AlertType.CONFIRMATION
						ButtonType buttonTypeYes = new ButtonType("͂", ButtonData.YES);
						ButtonType buttonTypeNo = new ButtonType("", ButtonData.NO);
						alert.getButtonTypes().setAll(buttonTypeYes, buttonTypeNo);
						alert.setContentText("͂ꂽO ZZ lłB\n΁u͂vԈĂ΁uvĉB");
					} else { // other than AlertType.CONFIRMATION
						ButtonType buttonType = new ButtonType("");
						alert.getButtonTypes().setAll(buttonType);
					}
				}
				Optional<ButtonType> result = alert.showAndWait();
				if (i == 1) { // AlertType.CONFIRMATION
					if (result.isPresent()) {
						if (result.get() == ButtonType.OK) {
							labelResult.setText("uOKv{^܂B");
						} else if (result.get() == ButtonType.CANCEL) {
							labelResult.setText("uv{^܂B");
						} else if (result.get().getButtonData() == ButtonData.YES) {
							labelResult.setText("u͂v{^܂B");
						} else if (result.get().getButtonData() == ButtonData.NO) {
							labelResult.setText("uv{^܂B");
						}
					}
				}
			}
    		
    	});
    	
    	buttonDialog.setOnAction(new EventHandler<ActionEvent>() {

			@Override
			public void handle(ActionEvent event) {
				resetResult();

				DialogFavoriteColor dialogFavoriteColor = new DialogFavoriteColor();
				Optional<Color> result = dialogFavoriteColor.showAndWait();
				if (result.isPresent()) {
					Color color = result.get();
					rectangle.setVisible(true);
					rectangle.setFill(color);
					rectangle.setStroke(color);
					labelResult.setTextFill(color);
					labelResult.setText("DȐFƂ #" + color.toString().substring(2, 8) + " I΂܂B");
				}
			}
    		
    	});
    	
    	buttonStage.setOnAction(new EventHandler<ActionEvent>() {

			@Override
			public void handle(ActionEvent event) {
				resetResult();
				
				StageAbout stageAbout = new StageAbout();
				stageAbout.setAppName("Alert, Dialog and Stage");
				stageAbout.showAndWait();
			}
    		
    	});
    }
    
    private void resetResult() {
		rectangle.setVisible(false);
		labelResult.setTextFill(Color.BLACK);
		labelResult.setText("");
    }
    
	public AlertDialogAndStageMainVBox() {
		
    	FXMLLoader fxmlLoader = new FXMLLoader(getClass().getResource("AlertDialogAndStageMainVBox.fxml"));
    	fxmlLoader.setRoot(this);
    	fxmlLoader.setController(this);
           	
    	try {
    		fxmlLoader.load();
    	} catch (IOException exception) {
    		throw new RuntimeException(exception);
    	}
    	
	}
	
}
